<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>About</name>
    <message>
        <source>Drumstick MIDI File Player Multiplatform</source>
        <translation>Reproductor Drumstick multiplataforma de archivos MIDI</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revisión</translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:20px; margin-bottom:20px; margin-left:20px; margin-right:20px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/dmidiplayer128.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;%PROJECT_DESCRIPTION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Version %VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Using &lt;/span&gt;&lt;a href=&quot;https://drumstick.sourceforge.io&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI C++ libraries &lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;v%DRUMSTICK_VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=dmidiplayer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, &lt;/span&gt;&lt;span style=&quot; font-family:&apos;Hack&apos;;&quot;&gt;see &amp;lt;&lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Hack&apos;;&quot;&gt;&amp;gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:20px; margin-bottom:20px; margin-left:20px; margin-right:20px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/dmidiplayer128.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;%PROJECT_DESCRIPTION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Versión %VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Usando &lt;/span&gt;&lt;a href=&quot;https://drumstick.sourceforge.io&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Bibliotecas Drumstick MIDI C++ &lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;v%DRUMSTICK_VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=dmidiplayer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Este programa es software libre: puede redistribuirlo y/o modificarlo bajo los términos de la Licencia General Pública de GNU publicada por la Free Software Foundation, ya sea la versión 3 de la Licencia, o (a su elección) cualquier versión posterior.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Este programa se distribuye con la esperanza de que sea útil pero SIN NINGUNA GARANTÍA; incluso sin la garantía implícita de MERCANTIBILIDAD o CALIFICADA PARA UN PROPÓSITO EN PARTICULAR. Vea la Licencia General Pública de GNU para más detalles.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Usted ha debido de recibir una copia de la Licencia General Pública de GNU junto con este programa. Si no, &lt;/span&gt;&lt;span style=&quot; font-family:&apos;Hack&apos;;&quot;&gt;vea &amp;lt;&lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Hack&apos;;&quot;&gt;&amp;gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>Channels</name>
    <message>
        <source>MIDI Channels</source>
        <translation>Canales MIDI</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Callar</translation>
    </message>
    <message>
        <source>Solo</source>
        <translation>Solo</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Fijar</translation>
    </message>
    <message>
        <source>Patch (sound setting)</source>
        <translation>Programa (sonido)</translation>
    </message>
    <message>
        <source>Show all channels</source>
        <translation>Mostrar todos los canales</translation>
    </message>
    <message>
        <source>Hide all channels</source>
        <translation>Ocultar todos los canales</translation>
    </message>
    <message>
        <source>View Full Screen</source>
        <translation>Ver en pantalla completa</translation>
    </message>
    <message>
        <source>Channel %1</source>
        <translation>Canal %1</translation>
    </message>
</context>
<context>
    <name>Connections</name>
    <message>
        <source>MIDI Output</source>
        <translation>Salida MIDI</translation>
    </message>
</context>
<context>
    <name>ConnectionsClass</name>
    <message>
        <source>Connections</source>
        <translation>Conexiones</translation>
    </message>
    <message>
        <source>Show advanced connections</source>
        <translation>Mostrar conexiones avanzadas</translation>
    </message>
    <message>
        <source>MIDI OUT</source>
        <translation>Salida MIDI</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>GUIPlayer</name>
    <message>
        <source>&lt;p&gt;This program is developed and translated thanks to the volunteer work of many people from around the world. If you want to join the team or have any question, please visit the web site at &lt;a href=&apos;http://sourceforge.net/projects/dmidiplayer/&apos;&gt;SourceForge&lt;/a&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Este programa es desarrollado y traducido gracias al trabajo voluntario de mucha gente de todo el mundo. Si usted quiere unirse al equipo o tiene alguna pregunta, por favor visite el sitio web en &lt;a href=&apos;http://sourceforge.net/projects/dmidiplayer/&apos;&gt;SourceForge&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Translation Information</source>
        <translation>Información de traducción</translation>
    </message>
    <message>
        <source>Language Changed</source>
        <translation>Cambio de idioma</translation>
    </message>
    <message>
        <source>The language for this application is going to change to %1. Do you want to continue?</source>
        <translation>El idioma para esta aplicación está a punto de cambiar a %1. ¿Desea continuar?</translation>
    </message>
    <message>
        <source>&lt;b&gt;No file loaded&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sin archivo&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;File:&lt;/b&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Archivo:&lt;/b&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;</source>
        <translation>&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Copyright:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Copyright:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke type:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Tipo de Karaoke:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke version:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Versión de Karaoke :&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke info:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Información de Karaoke:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke language:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Idioma del Karaoke:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke title:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Título del Karaoke:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Karaoke things:&lt;/b&gt;%1&lt;br&gt;</source>
        <translation type="vanished">&lt;b&gt;Cosas del Karaoke:&lt;/b&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>SMF Information</source>
        <translation>Información del SMF</translation>
    </message>
    <message>
        <source>Open MIDI File</source>
        <translation>Abrir archivo MIDI</translation>
    </message>
    <message>
        <source>All files (*.kar *.mid *.midi *.wrk);;Karaoke files (*.kar);;MIDI Files (*.mid *.midi);;Cakewalk files (*.wrk)</source>
        <translation type="vanished">Todos los archivos (*.kar *.mid *.midi *.wrk);;Archivos de Karaoke (*.kar);;Archivos MIDI (*.mid *.midi);;Archivos de Cakewalk (*.wrk)</translation>
    </message>
    <message>
        <source>Playlist not saved</source>
        <translation>Lista de reproducción sin guardar</translation>
    </message>
    <message>
        <source>The current playlist has changed, but it is not saved. The changes will be lost when closing the program.</source>
        <translation>La lista de reproducción actual ha cambiado, pero no ha sido guardada. Los cambios se perderán al cerrar el programa.</translation>
    </message>
    <message>
        <source>Jump to Bar</source>
        <translation>Saltar al compás</translation>
    </message>
    <message>
        <source>Bar number:</source>
        <translation>Número de compás:</translation>
    </message>
    <message>
        <source>Please, load a song</source>
        <translation>Por favor, cargue una canción</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation>Reproduciendo</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
    <message>
        <source>Not initialized</source>
        <translation>Sin inicializar</translation>
    </message>
    <message>
        <source>Loading %1 file...</source>
        <translation>Cargando archivo %1...</translation>
    </message>
    <message>
        <source>file %1 couldn&apos;t be opened</source>
        <translation>archivo %1 no ha podido abrirse</translation>
    </message>
    <message>
        <source>Dropped file %1 is not supported</source>
        <translation>Archivo %1 soltado no está soportado</translation>
    </message>
    <message>
        <source>All files (*.kar *.mid *.midi *.rmi *.wrk);;Karaoke files (*.kar);;MIDI Files (*.mid *.midi);;RIFF MIDI Files (*.rmi);;Cakewalk files (*.wrk)</source>
        <translation>Todos los archivos (*.kar *.mid *.midi *.rmi *.wrk);;Archivos de Karaoke (*.kar);;Archivos MIDI (*.mid *.midi);;Archivos MIDI RIFF (*.rmi);;Archivos de Cakewalk (*.wrk)</translation>
    </message>
    <message>
        <source>File: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Archivo: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Format: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Formato: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Copyright: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Copyright: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke type: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Tipo de karaoke: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke version: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Versi
Versión de karaoke: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke info: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Información de karaoke: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke language: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Idiooma de karaoke: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke title: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Título de karaoke: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Karaoke things: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</source>
        <translation>Varios: &lt;b&gt;%1&lt;/b&gt;&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>GUIPlayerClass</name>
    <message>
        <source>Drumstick MIDI Player</source>
        <translation>Reproductor MIDI Drumstick</translation>
    </message>
    <message>
        <source>Playback time and current levels</source>
        <translation>Tiempo de reproducción y niveles actuales</translation>
    </message>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Tempo:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <source>Volume:</source>
        <translation>Volumen:</translation>
    </message>
    <message>
        <source>Pitch:</source>
        <translation>Tono:</translation>
    </message>
    <message>
        <source>Pitch Control</source>
        <translation>Control de tono</translation>
    </message>
    <message>
        <source>Pitch transpose between -12 and +12 semitones</source>
        <translation>Transporte del tono entre -12 y +12 semitonos</translation>
    </message>
    <message>
        <source>Reset Volume</source>
        <translation>Restablecer volumen</translation>
    </message>
    <message>
        <source>Reset Volume to 100%</source>
        <translation>Restablecer volumen al 100%</translation>
    </message>
    <message>
        <source>Volume Slider</source>
        <translation>Deslizador de volumen</translation>
    </message>
    <message>
        <source>Playback progress</source>
        <translation type="vanished">Progreso de reproducción</translation>
    </message>
    <message>
        <source>File Name:</source>
        <translation>Nombre de archivo:</translation>
    </message>
    <message>
        <source>Currently loaded MIDI file name</source>
        <translation>Nombre de archivo MIDI actual</translation>
    </message>
    <message>
        <source>Tempo Slider</source>
        <translation>Deslizador de tempo</translation>
    </message>
    <message>
        <source>Reset Tempo</source>
        <translation>Restablecer tempo</translation>
    </message>
    <message>
        <source>Reset Tempo to 100%</source>
        <translation>Restablecer el tempo al 100%</translation>
    </message>
    <message>
        <source>tempo=100%</source>
        <translation>tempo=100%</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Ayuda</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>Tool Bar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open a MIDI file</source>
        <translation>Abrir un archivo MIDI</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Terminar</translation>
    </message>
    <message>
        <source>Quit the application</source>
        <translation>Terminar la aplicación</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Start playing the current MIDI file</source>
        <translation>Iniciar la reproducción del archivo MIDI actual</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Pause the playback</source>
        <translation type="vanished">Pausar la reproducción</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop the playback</source>
        <translation type="vanished">Parar la reproducción</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Show the about box</source>
        <translation>Mostrar el cuadro de Acerca de</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <source>Show the about Qt dialog box</source>
        <translation>Mostrar el cuadro de Acerca de Qt</translation>
    </message>
    <message>
        <source>MIDI Setup</source>
        <translation>Ajustes MIDI</translation>
    </message>
    <message>
        <source>Select a connection for the MIDI output port</source>
        <translation>Seleccionar una conexión para el puerto de salida MIDI</translation>
    </message>
    <message>
        <source>Show Tool Bar</source>
        <translation>Mostrar la barra de herramientas</translation>
    </message>
    <message>
        <source>Show or hide the tool bar</source>
        <translation>Mostrar u ocultar la barra de herramientas</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Mostrar la barra de estado</translation>
    </message>
    <message>
        <source>Show or hide the status bar</source>
        <translation>Mostar u ocultar la barra de estado</translation>
    </message>
    <message>
        <source>Drumstick MIDI File Player Multiplatform</source>
        <translation>Reproductor Drumstick multiplataforma de archivos MIDI</translation>
    </message>
    <message>
        <source>Open Recent Files</source>
        <translation>Abrir archivos recientes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Lyrics and Texts</source>
        <translation>Letras y textos</translation>
    </message>
    <message>
        <source>Show or Hide Lyrics and Texts</source>
        <translation>Mostrar u ocultar letras y textos</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="vanished">Lista de reproducción</translation>
    </message>
    <message>
        <source>Show or Hide Playlist</source>
        <translation type="vanished">Mostrar u ocultar lista de reproducción</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <source>Show or Hide Channels</source>
        <translation>Mostrar u ocultar canales</translation>
    </message>
    <message>
        <source>Piano Player</source>
        <translation>Pianola</translation>
    </message>
    <message>
        <source>Show or Hide Piano Player</source>
        <translation>Mostrar u ocultar pianola</translation>
    </message>
    <message>
        <source>Rhythm</source>
        <translation>Ritmo</translation>
    </message>
    <message>
        <source>Show or Hide Rhythm</source>
        <translation>Mostrar u ocultar ritmo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;Language</source>
        <translation>&amp;Idioma</translation>
    </message>
    <message>
        <source>File Info</source>
        <translation>Información del archivo</translation>
    </message>
    <message>
        <source>Preferences ...</source>
        <translation>Preferencias ...</translation>
    </message>
    <message>
        <source>Play List ...</source>
        <translation>Lista de reproducción ...</translation>
    </message>
    <message>
        <source>Show Play List Editor</source>
        <translation>Mostrar editor de lista de reproducción</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Prev</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Playlist Repeat</source>
        <translation>Repetición de la lista de reproducción</translation>
    </message>
    <message>
        <source>Pause  playback</source>
        <translation>Pausar reproducción</translation>
    </message>
    <message>
        <source>Stop playback</source>
        <translation>Parar reproducción</translation>
    </message>
    <message>
        <source>Next File</source>
        <translation>Siguiente archivo</translation>
    </message>
    <message>
        <source>Previous File</source>
        <translation>Archivo anterior</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avanzar</translation>
    </message>
    <message>
        <source>Move play position to the next bar</source>
        <translation>Mover la posición de reproducción al siguiente compás</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation>Retroceder</translation>
    </message>
    <message>
        <source>Move play position to the previous bar</source>
        <translation>Mover la posición de reproducción al compás anterior</translation>
    </message>
    <message>
        <source>Jump...</source>
        <translation>Saltar...</translation>
    </message>
    <message>
        <source>Move play position to any bar</source>
        <translation>Mover la posición de reproducción a cualquier compás</translation>
    </message>
    <message>
        <source>Customize Tool Bar...</source>
        <translation>Personalizar la barra de herramientas...</translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation>Nada</translation>
    </message>
    <message>
        <source>Current Song</source>
        <translation>Canción actual</translation>
    </message>
    <message>
        <source>Whole Playlist</source>
        <translation>Toda la lista de reproducción</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Bucle</translation>
    </message>
    <message>
        <source>Loop between two bars</source>
        <translation>Bucle entre dos compases</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Contenido</translation>
    </message>
    <message>
        <source>Web Site</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Song Settings</source>
        <translation>Ajustes de canción</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Load the stored settings for the current song</source>
        <translation>Cargar los ajustes almacenados para la canción actual</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Save the settings of the current song</source>
        <translation>Guardar los ajustes para la canción actual</translation>
    </message>
    <message>
        <source>Search MIDI files</source>
        <translation>Buscar archivos MIDI</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Inicio</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <source>Help: %1</source>
        <translation type="vanished">Ayuda: %1</translation>
    </message>
</context>
<context>
    <name>InstrumentSet</name>
    <message>
        <source>Acoustic Grand Piano</source>
        <translation>Piano de cola</translation>
    </message>
    <message>
        <source>Bright Acoustic Piano</source>
        <translation>Piano de cola brillante</translation>
    </message>
    <message>
        <source>Electric Grand Piano</source>
        <translation>Piano de cola eléctrico</translation>
    </message>
    <message>
        <source>Honky-Tonk</source>
        <translation>Piano de cantina</translation>
    </message>
    <message>
        <source>Rhodes Piano</source>
        <translation>Piano Rhodes</translation>
    </message>
    <message>
        <source>Chorused Piano</source>
        <translation>Piano con coro</translation>
    </message>
    <message>
        <source>Harpsichord</source>
        <translation>Clavicordio</translation>
    </message>
    <message>
        <source>Clavinet</source>
        <translation>Clavinet</translation>
    </message>
    <message>
        <source>Celesta</source>
        <translation>Celesta</translation>
    </message>
    <message>
        <source>Glockenspiel</source>
        <translation>Glockenspiel</translation>
    </message>
    <message>
        <source>Music Box</source>
        <translation>Caja de música</translation>
    </message>
    <message>
        <source>Vibraphone</source>
        <translation>Vibráfono</translation>
    </message>
    <message>
        <source>Marimba</source>
        <translation>Marimba</translation>
    </message>
    <message>
        <source>Xylophone</source>
        <translation>Xilófono</translation>
    </message>
    <message>
        <source>Tubular Bells</source>
        <translation>Campanas tubulares</translation>
    </message>
    <message>
        <source>Dulcimer</source>
        <translation>Dulcémele</translation>
    </message>
    <message>
        <source>Hammond Organ</source>
        <translation>Órgano Hammond</translation>
    </message>
    <message>
        <source>Percussive Organ</source>
        <translation>Órgano percusivo</translation>
    </message>
    <message>
        <source>Rock Organ</source>
        <translation>Órgano de rock</translation>
    </message>
    <message>
        <source>Church Organ</source>
        <translation>Órgano de iglesia</translation>
    </message>
    <message>
        <source>Reed Organ</source>
        <translation>Armonio</translation>
    </message>
    <message>
        <source>Accordion</source>
        <translation>Acordeón</translation>
    </message>
    <message>
        <source>Harmonica</source>
        <translation>Armónica</translation>
    </message>
    <message>
        <source>Tango Accordion</source>
        <translation>Bandoneón</translation>
    </message>
    <message>
        <source>Acoustic Guitar (Nylon)</source>
        <translation>Guitarra española</translation>
    </message>
    <message>
        <source>Acoustic Guitar (Steel)</source>
        <translation>Guitarra acústica (metal)</translation>
    </message>
    <message>
        <source>Electric Guitar (Jazz)</source>
        <translation>Guitarra eléctrica (jazz)</translation>
    </message>
    <message>
        <source>Electric Guitar (Clean)</source>
        <translation>Guitarra eléctrica (limpia)</translation>
    </message>
    <message>
        <source>Electric Guitar (Muted)</source>
        <translation>Guitarra eléctrica (con sordina)</translation>
    </message>
    <message>
        <source>Overdriven Guitar</source>
        <translation>Guitarra sobre-saturada</translation>
    </message>
    <message>
        <source>Distortion Guitar</source>
        <translation>Guitarra con distorsión</translation>
    </message>
    <message>
        <source>Guitar Harmonics</source>
        <translation>Armónicos de guitarra</translation>
    </message>
    <message>
        <source>Acoustic Bass</source>
        <translation>Bajo acústico</translation>
    </message>
    <message>
        <source>Electric Bass (Finger)</source>
        <translation>Bajo eléctrico (pulsado)</translation>
    </message>
    <message>
        <source>Electric Bass (Pick)</source>
        <translation>Bajo eléctrico (punteado)</translation>
    </message>
    <message>
        <source>Fretless Bass</source>
        <translation>Bajo sin trastes</translation>
    </message>
    <message>
        <source>Slap Bass 1</source>
        <translation>Bajo palmeado 1</translation>
    </message>
    <message>
        <source>Slap Bass 2</source>
        <translation>Bajo palmeado 2</translation>
    </message>
    <message>
        <source>Synth Bass 1</source>
        <translation>Bajo sintetizado 1</translation>
    </message>
    <message>
        <source>Synth Bass 2</source>
        <translation>Bajo sintetizado 2</translation>
    </message>
    <message>
        <source>Violin</source>
        <translation>Violín</translation>
    </message>
    <message>
        <source>Viola</source>
        <translation>Viola</translation>
    </message>
    <message>
        <source>Cello</source>
        <translation>Violoncelo</translation>
    </message>
    <message>
        <source>Contrabass</source>
        <translation>Contrabajo</translation>
    </message>
    <message>
        <source>Tremolo Strings</source>
        <translation>Cuerdas con trémolo</translation>
    </message>
    <message>
        <source>Pizzicato Strings</source>
        <translation>Cuerdas con pizzicato</translation>
    </message>
    <message>
        <source>Orchestral Harp</source>
        <translation>Arpa orquestal</translation>
    </message>
    <message>
        <source>Timpani</source>
        <translation>Timbales</translation>
    </message>
    <message>
        <source>String Ensemble 1</source>
        <translation>Conjunto de cuerdas 1</translation>
    </message>
    <message>
        <source>String Ensemble 2</source>
        <translation>Conjunto de cuerdas 2</translation>
    </message>
    <message>
        <source>Synth Strings 1</source>
        <translation>Cuerdas sintetizadas 1</translation>
    </message>
    <message>
        <source>Synth Strings 2</source>
        <translation>Cuerdas sintetizadas 2</translation>
    </message>
    <message>
        <source>Choir Aahs</source>
        <translation>Coro aahs</translation>
    </message>
    <message>
        <source>Voice Oohs</source>
        <translation>Voz oohs</translation>
    </message>
    <message>
        <source>Synth Voice</source>
        <translation>Voz sintetizada</translation>
    </message>
    <message>
        <source>Orchestra Hit</source>
        <translation>Golpe de orquesta</translation>
    </message>
    <message>
        <source>Trumpet</source>
        <translation>Trompeta</translation>
    </message>
    <message>
        <source>Trombone</source>
        <translation>Trombón</translation>
    </message>
    <message>
        <source>Tuba</source>
        <translation>Tuba</translation>
    </message>
    <message>
        <source>Muted Trumpet</source>
        <translation>Trompeta con sordina</translation>
    </message>
    <message>
        <source>French Horn</source>
        <translation>Trompa</translation>
    </message>
    <message>
        <source>Brass Section</source>
        <translation>Sección de metal</translation>
    </message>
    <message>
        <source>Synth Brass 1</source>
        <translation>Metales sintetizados 1</translation>
    </message>
    <message>
        <source>Synth Brass 2</source>
        <translation>Metales sintetizados 2</translation>
    </message>
    <message>
        <source>Soprano Sax</source>
        <translation>Saxo soprano</translation>
    </message>
    <message>
        <source>Alto Sax</source>
        <translation>Saxo alto</translation>
    </message>
    <message>
        <source>Tenor Sax</source>
        <translation>Saxo tenor</translation>
    </message>
    <message>
        <source>Baritone Sax</source>
        <translation>Saxo barítono</translation>
    </message>
    <message>
        <source>Oboe</source>
        <translation>Oboe</translation>
    </message>
    <message>
        <source>English Horn</source>
        <translation>Corno inglés</translation>
    </message>
    <message>
        <source>Bassoon</source>
        <translation>Fagot</translation>
    </message>
    <message>
        <source>Clarinet</source>
        <translation>Clarinete</translation>
    </message>
    <message>
        <source>Piccolo</source>
        <translation>Flautín</translation>
    </message>
    <message>
        <source>Flute</source>
        <translation>Flauta</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Flauta dulce</translation>
    </message>
    <message>
        <source>Pan Flute</source>
        <translation>Flauta de pan</translation>
    </message>
    <message>
        <source>Blown Bottle</source>
        <translation>Soplo de botella</translation>
    </message>
    <message>
        <source>Shakuhachi</source>
        <translation>Shakuhachi</translation>
    </message>
    <message>
        <source>Whistle</source>
        <translation>Silbido</translation>
    </message>
    <message>
        <source>Ocarina</source>
        <translation>Ocarina</translation>
    </message>
    <message>
        <source>Lead 1 - Square Wave</source>
        <translation>Melodía 1 - Onda cuadrada</translation>
    </message>
    <message>
        <source>Lead 2 - Saw Tooth</source>
        <translation>Melodía 2 - Onda dentada</translation>
    </message>
    <message>
        <source>Lead 3 - Calliope</source>
        <translation>Melodía 3 - Calíope</translation>
    </message>
    <message>
        <source>Lead 4 - Chiflead</source>
        <translation>Melodía 4 - Siseo</translation>
    </message>
    <message>
        <source>Lead 5 - Charang</source>
        <translation>Melodía 5 - Charango</translation>
    </message>
    <message>
        <source>Lead 6 - Voice</source>
        <translation>Melodía 6 - Voz</translation>
    </message>
    <message>
        <source>Lead 7 - Fifths</source>
        <translation>Melodía 7 - Quintas</translation>
    </message>
    <message>
        <source>Lead 8 - Bass+Lead</source>
        <translation>Melodía 8 - Bajo+melodía</translation>
    </message>
    <message>
        <source>Pad 1 - New Age</source>
        <translation>Fondo 1 - Nueva era</translation>
    </message>
    <message>
        <source>Pad 2 - Warm</source>
        <translation>Fondo 2 - Cálido</translation>
    </message>
    <message>
        <source>Pad 3 - Polysynth</source>
        <translation>Fondo 3 - Polisintético</translation>
    </message>
    <message>
        <source>Pad 4 - Choir</source>
        <translation>Fondo 4 - Coros</translation>
    </message>
    <message>
        <source>Pad 5 - Bow</source>
        <translation>Fondo 5 - De arco</translation>
    </message>
    <message>
        <source>Pad 6 - Metallic</source>
        <translation>Fondo 6 - Metálico</translation>
    </message>
    <message>
        <source>Pad 7 - Halo</source>
        <translation>Fondo 7 - Celestial</translation>
    </message>
    <message>
        <source>Pad 8 - Sweep</source>
        <translation>Fondo 8 - Escobillas</translation>
    </message>
    <message>
        <source>FX 1 - Rain</source>
        <translation>Efecto 1 - Lluvia</translation>
    </message>
    <message>
        <source>FX 2 - Soundtrack</source>
        <translation>Efecto 2 - Banda sonora</translation>
    </message>
    <message>
        <source>FX 3 - Crystal</source>
        <translation>Efecto 3 - Cristal</translation>
    </message>
    <message>
        <source>FX 4 - Atmosphere</source>
        <translation>Efecto 4 - Atmósfera</translation>
    </message>
    <message>
        <source>FX 5 - Brightness</source>
        <translation>Efecto 5 - Brillo</translation>
    </message>
    <message>
        <source>FX 6 - Goblins</source>
        <translation>Efecto 6 - Duendes</translation>
    </message>
    <message>
        <source>FX 7 - Echoes</source>
        <translation>Efecto 7 - Ecos</translation>
    </message>
    <message>
        <source>FX 8 - Sci-fi</source>
        <translation>Efecto 8 - Ci-fi</translation>
    </message>
    <message>
        <source>Sitar</source>
        <translation>Sitar</translation>
    </message>
    <message>
        <source>Banjo</source>
        <translation>Banjo</translation>
    </message>
    <message>
        <source>Shamisen</source>
        <translation>Shamisen</translation>
    </message>
    <message>
        <source>Koto</source>
        <translation>Koto</translation>
    </message>
    <message>
        <source>Kalimba</source>
        <translation>Kalimba</translation>
    </message>
    <message>
        <source>Bagpipe</source>
        <translation>Gaita</translation>
    </message>
    <message>
        <source>Fiddle</source>
        <translation>Violín popular</translation>
    </message>
    <message>
        <source>Shannai</source>
        <translation>Shannai</translation>
    </message>
    <message>
        <source>Tinkle Bell</source>
        <translation>Campanilla</translation>
    </message>
    <message>
        <source>Agogo</source>
        <translation>Agogó</translation>
    </message>
    <message>
        <source>Steel Drum</source>
        <translation>Tambor metálico</translation>
    </message>
    <message>
        <source>Wood Block</source>
        <translation>Bloque de madera</translation>
    </message>
    <message>
        <source>Taiko Drum</source>
        <translation>Tambor Taiko</translation>
    </message>
    <message>
        <source>Melodic Tom</source>
        <translation>Timbal melódico</translation>
    </message>
    <message>
        <source>Synth Drum</source>
        <translation>Tambor sintetizado</translation>
    </message>
    <message>
        <source>Reverse Cymbal</source>
        <translation>Platillo invertido</translation>
    </message>
    <message>
        <source>Guitar Fret Noise</source>
        <translation>Ruido de trasteo de guitarra</translation>
    </message>
    <message>
        <source>Breath Noise</source>
        <translation>Ruido de respiración</translation>
    </message>
    <message>
        <source>Seashore</source>
        <translation>Orilla del mar</translation>
    </message>
    <message>
        <source>Bird Tweet</source>
        <translation>Piar de pájaros</translation>
    </message>
    <message>
        <source>Telephone</source>
        <translation>Teléfono</translation>
    </message>
    <message>
        <source>Helicopter</source>
        <translation>Helicóptero</translation>
    </message>
    <message>
        <source>Applause</source>
        <translation>Aplausos</translation>
    </message>
    <message>
        <source>Gunshot</source>
        <translation>Disparo</translation>
    </message>
    <message>
        <source>Percussion %1</source>
        <translation>Percusión %1</translation>
    </message>
</context>
<context>
    <name>LoopDialog</name>
    <message>
        <source>Loop Start and End bars</source>
        <translation>Compases de inicio y fin</translation>
    </message>
    <message>
        <source>Loop Start:</source>
        <translation>Compás inicial:</translation>
    </message>
    <message>
        <source>Loop End:</source>
        <translation>Compás final:</translation>
    </message>
    <message>
        <source>Input Error</source>
        <translation>Error de entrada</translation>
    </message>
    <message>
        <source>%1 is not greater than %2</source>
        <translation>%1 no es mayor que %2</translation>
    </message>
</context>
<context>
    <name>Lyrics</name>
    <message>
        <source>Lyrics Viewer</source>
        <translation type="vanished">Visor de letras</translation>
    </message>
    <message>
        <source>Lyrics</source>
        <translation type="vanished">Letras</translation>
    </message>
    <message>
        <source>Track:</source>
        <translation>Pista:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>All Types</source>
        <translation>Todos los tipos</translation>
    </message>
    <message>
        <source>Texts</source>
        <translation>Textos</translation>
    </message>
    <message>
        <source>Copyright Notice</source>
        <translation>Nota de copyright</translation>
    </message>
    <message>
        <source>Sequence Name</source>
        <translation>Nombre de secuencia</translation>
    </message>
    <message>
        <source>Instrument Name</source>
        <translation>Nombre de instrumento</translation>
    </message>
    <message>
        <source>Lyric Events</source>
        <translation>Eventos de letra</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Cue Point</source>
        <translation>Señal</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Codificación:</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation type="vanished">Fuente:</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation>Todas las pistas</translation>
    </message>
    <message>
        <source>Track %1</source>
        <translation>Pista %1</translation>
    </message>
    <message>
        <source>Lyrics Viewer (%1)</source>
        <translation type="vanished">Visor de letra (%1)</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Fuente</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Default (latin1)</source>
        <translation>Por omisión (latin1)</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Fuente...</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <source>Save to file...</source>
        <translation>Guardar en un archivo...</translation>
    </message>
    <message>
        <source>Print...</source>
        <translation>Imprimir...</translation>
    </message>
</context>
<context>
    <name>Pianola</name>
    <message>
        <source>Player Piano</source>
        <translation>Pianola</translation>
    </message>
    <message>
        <source>MIDI Channels</source>
        <translation type="vanished">Canales MIDI</translation>
    </message>
    <message>
        <source>Show all channels</source>
        <translation>Mostrar todos los canales</translation>
    </message>
    <message>
        <source>Hide all channels</source>
        <translation>Ocultar todos los canales</translation>
    </message>
    <message>
        <source>Tighten the number of keys</source>
        <translation>Ajustar el número de teclas</translation>
    </message>
    <message>
        <source>Channel %1</source>
        <translation>Canal %1</translation>
    </message>
    <message>
        <source>View Full Screen</source>
        <translation>Ver en pantalla completa</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <source>Manage Playlist</source>
        <translation>Gestionar lista de reproducción</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Mover Arriba</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Mover abajo</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <source>Open Playlist file</source>
        <translation>Abrir archivo de lista de reproducción</translation>
    </message>
    <message>
        <source>Playlist (*.lst)</source>
        <translation>Lista de reproducción (*.lst)</translation>
    </message>
    <message>
        <source>Save Playlist file</source>
        <translation>Guardar lista de reproducción</translation>
    </message>
    <message>
        <source>Add MIDI File</source>
        <translation>Añadir archivo MIDI</translation>
    </message>
    <message>
        <source>All files (*.kar *.mid *.midi *.wrk);;Karaoke files (*.kar);;MIDI Files (*.mid *.midi);;Cakewalk files (*.wrk)</source>
        <translation>Todos los archivos (*.kar *.mid *.midi *.wrk);;Archivos de Karaoke (*.kar);;Archivos MIDI (*.mid *.midi);;Archivos de Cakewalk (*.wrk)</translation>
    </message>
    <message>
        <source>Shuffle</source>
        <translation>Aleatorizar</translation>
    </message>
    <message>
        <source>Manage Playlist: %1 %2</source>
        <translation>Gestionar listas de reproducción: %1 %2</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Diálogo</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Percussion MIDI Channel</source>
        <translation type="vanished">Canal MIDI de percusión</translation>
    </message>
    <message>
        <source>Sticky Window Snapping</source>
        <translation type="vanished">Acoplamiento de ventanas pegajosas</translation>
    </message>
    <message>
        <source>Forced Dark Mode</source>
        <translation>Modo oscuro forzado</translation>
    </message>
    <message>
        <source>Start Playback Automatically After Loading</source>
        <translation>Iniciar reproducción automáticamente después de cargar</translation>
    </message>
    <message>
        <source>Lyrics</source>
        <translation>Letras</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Future Text Color</source>
        <translation>Color del texto futuro</translation>
    </message>
    <message>
        <source>Text Font</source>
        <translation>Fuente del texto</translation>
    </message>
    <message>
        <source>Past Text Color</source>
        <translation>Color de texto pasado</translation>
    </message>
    <message>
        <source>Player Piano</source>
        <translation>Pianola</translation>
    </message>
    <message>
        <source>Single Highlight Color</source>
        <translation>Color de resaltado único</translation>
    </message>
    <message>
        <source>Note Highlighting</source>
        <translation>Resaltado de notas</translation>
    </message>
    <message>
        <source>Show Note Names</source>
        <translation>Mostrar nombres de notas</translation>
    </message>
    <message>
        <source>Note Names Font</source>
        <translation>Fuente de nombres de notas</translation>
    </message>
    <message>
        <source>Note Velocity to Color Tint</source>
        <translation>Velocidad MIDI a matiz de color</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ninca</translation>
    </message>
    <message>
        <source>Minimal</source>
        <translation>Mínima</translation>
    </message>
    <message>
        <source>When Activated</source>
        <translation>Cuando se activen</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Siempre</translation>
    </message>
    <message>
        <source>Use Internal Icon Theme</source>
        <translation>Usar tema de iconos interno</translation>
    </message>
    <message>
        <source>Qt Widgets Style:</source>
        <translation>Estilo de componentes de Qt:</translation>
    </message>
    <message>
        <source>Percussion MIDI Channel:</source>
        <translation>Canal MIDI de percusión:</translation>
    </message>
    <message>
        <source>MIDI System Exclusive Reset:</source>
        <translation>Reinicio de sistema exclusivo MIDI:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>GM</source>
        <translation>GM</translation>
    </message>
    <message>
        <source>GS</source>
        <translation>GS</translation>
    </message>
    <message>
        <source>XG</source>
        <translation>XG</translation>
    </message>
    <message>
        <source>Advance Automatically to the Next Playlist item</source>
        <translation>Avance automático en la lista de reproducción</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>Solo Button % Volume Reduction:</source>
        <translation>Reducción de volumen % del botón Solo:</translation>
    </message>
    <message>
        <source>Sticky Window Borders</source>
        <translation>Bordes de ventana pegajosos</translation>
    </message>
    <message>
        <source>Automatically Load and Save Song Settings</source>
        <translation>Cargar y guardar automáticamente los ajustes de canción</translation>
    </message>
    <message>
        <source>Octave Subscript Designation</source>
        <translation>Designación de octava como subíndice</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <source>Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
This program comes with ABSOLUTELY NO WARRANTY;
This is free software, and you are welcome to redistribute it
under certain conditions; see the LICENSE for details.</source>
        <translation>Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
Este programa no tiene ABSOLUTAMENTE NINGUNA GARANTÍA;
Esto es software libre; y usted puede redistribuirlo
bajo ciertas condiciones; vea LICENSE para detalles.</translation>
    </message>
    <message>
        <source>Fatal error from the Operating System. This usually happens when the OS doesn&apos;t have MIDI support, or the MIDI support is not enabled. Please check your OS/MIDI configuration.</source>
        <translation>Error fatal desde el sistema operativo. Esto ocurre normalmente cuando el S.O. no tiene soporte MIDI, o el soporte MIDI no está habilitado. Por favor, compruebe su configuración del S.O./MIDI.</translation>
    </message>
    <message>
        <source>Portable settings mode.</source>
        <translation>Modo portable de ajustes.</translation>
    </message>
    <message>
        <source>Portable settings file name.</source>
        <translation>Nombre de archivo de ajustes portable.</translation>
    </message>
    <message>
        <source>MIDI Out Driver.</source>
        <translation>Controlador de salida MIDI.</translation>
    </message>
    <message>
        <source>MIDI Out Connection.</source>
        <translation>Conexión de salida MIDI.</translation>
    </message>
    <message>
        <source>Input SMF/KAR/WRK file name.</source>
        <translation>Nombre de archivo SMF/KAR/WRK de entrada.</translation>
    </message>
    <message>
        <source>File not found:</source>
        <translation>Archivo no encontrado:</translation>
    </message>
</context>
<context>
    <name>RecentFilesHelper</name>
    <message>
        <source>Clear recent files</source>
        <translation>Limpiar archivos recientes</translation>
    </message>
    <message>
        <source>&amp;%1 %2</source>
        <translation>&amp;%1 %2</translation>
    </message>
</context>
<context>
    <name>Sequence</name>
    <message>
        <source> in RIFF container of type %1</source>
        <translation> en contenedor RIFF de tipo %1</translation>
    </message>
    <message>
        <source>SMF type %1</source>
        <translation>SMF tipo %1</translation>
    </message>
    <message>
        <source>WRK file version v%1.%2</source>
        <translation>versión de archivo WRK v%1.%2</translation>
    </message>
</context>
<context>
    <name>ToolBarEditDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Diálogo</translation>
    </message>
    <message>
        <source>remove</source>
        <translation>eliminar</translation>
    </message>
    <message>
        <source>add</source>
        <translation>añadir</translation>
    </message>
    <message>
        <source>up</source>
        <translation>arriba</translation>
    </message>
    <message>
        <source>down</source>
        <translation>abajo</translation>
    </message>
    <message>
        <source>Icon Only</source>
        <translation>Solo icono</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Solo texto</translation>
    </message>
    <message>
        <source>Text Beside Icon</source>
        <translation>Texto junto a icono</translation>
    </message>
    <message>
        <source>Text Under Icon</source>
        <translation>Texto bajo icono</translation>
    </message>
    <message>
        <source>Follow Style</source>
        <translation>Seguir estilo</translation>
    </message>
    <message>
        <source>Style of the Tool Buttons</source>
        <translation>Estilo de los botones</translation>
    </message>
    <message>
        <source>Available Actions</source>
        <translation>Acciones disponibles</translation>
    </message>
    <message>
        <source>Selected Actions</source>
        <translation>Acciones seleccionadas</translation>
    </message>
    <message>
        <source>Customize %1</source>
        <translation>Personalizar %1</translation>
    </message>
    <message>
        <source>Tool Bar Editor</source>
        <translation>Editor de barra de herramientas</translation>
    </message>
</context>
</TS>
